"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.ValidationOptionChecks = void 0;
const defined_1 = require("../base/defined");
const ContentDataTypes_1 = require("./ContentDataTypes");
/**
 * A class for checking the settings that are stored
 * in a `ValidationOptions` object, and determine
 * whether (and how) certain validation steps should
 * be performed.
 *
 * @internal
 */
class ValidationOptionChecks {
    /**
     * Examines the given validation options, to see whether the given
     * content data should be validated.
     *
     * @param options - The validation options
     * @param contentData - The content data
     * @returns Whether the content data should be validated
     */
    static async shouldValidate(options, contentData) {
        if (!options.validateContentData) {
            return false;
        }
        const name = await ContentDataTypes_1.ContentDataTypes.nameFor(contentData);
        if (!(0, defined_1.defined)(name)) {
            return false;
        }
        let isIncluded = true;
        let isExcluded = false;
        const included = options.includeContentTypes;
        if ((0, defined_1.defined)(included)) {
            isIncluded = included.includes(name);
        }
        const excluded = options.excludeContentTypes;
        if ((0, defined_1.defined)(excluded)) {
            isExcluded = excluded.includes(name);
        }
        return isIncluded && !isExcluded;
    }
}
exports.ValidationOptionChecks = ValidationOptionChecks;
